pub struct Truncated {
pub bytes: usize,
pub over: usize,
}Expand description
A byte sequence that is not a whole number of instructions.
Fields
bytes: usizeHow many bytes there were.
over: usizeHow many of them are left over after the last whole instruction.